@@ -2,8 +2,23 @@
 # pylint: disable=protected-access, broad-except
 import logging
 from re import sub
+from copy import deepcopy
+from es_client.defaults import KEYS_TO_REDACT
 from es_client.exceptions import ConfigurationError
 
+def password_filter(data):
+    """
+    Return a deepcopy of the dictionary with any password fields hidden
+    """
+    def iterdict(mydict):
+        for key, value in mydict.items():
+            if isinstance(value, dict):
+                iterdict(value)
+            elif key in KEYS_TO_REDACT:
+                mydict.update({key: "REDACTED"})
+        return mydict
+    return iterdict(deepcopy(data))
+
 class SchemaCheck(object):
     """
     Validate ``config`` with the provided :class:`voluptuous.Schema <voluptuous.schema_builder.Schema>`.
@@ -26,7 +41,7 @@ class SchemaCheck(object):
         self.logger = logging.getLogger(__name__)
         # Set the Schema for validation...
         self.logger.debug('Schema: %s', schema)
-        self.logger.debug('"%s" config: %s', test_what, config)
+        self.logger.debug('"%s" config: %s', test_what, password_filter(config))
         self.config = config
         self.schema = schema
         self.test_what = test_what
@@ -47,7 +62,7 @@ class SchemaCheck(object):
                     key = int(k)
                 except ValueError:
                     key = k
-                if value == None:
+                if value is None:
                     value = data[key]
                     # if this fails, it's caught below
             return value
